@@ -11,8 +11,9 @@
 										"\n", "                ---------------------", "\n",
 										"\n", "  Spatial Analysis of Phenotypic, Genotypic and Environmental Data",
 										"\n",
-										"\n", "  Version",  vers, "\t\t",
-										" <leandroroser@ege.fcen.uba.ar>", "\n\n",
+										"\n", "  Version",  vers, "\n\n",
+										"  GitHub: https://github.com/leandroroser/EcoGenetics-devel", "\n\n",
+										"  Online tutorial: https://github.com/leandroroser/EcoGenetics-Tutorial", "\n\n",
 										"  Overview: help('EcoGenetics')")
 	
 	packageStartupMessage(textstart)
